"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.argumentMapper = void 0;
const logger_1 = require("../../logger");
const argumentMapper = (argMapping, options) => Object.keys(options)
    .map((key) => {
    if (!argMapping[key]) {
        logger_1.default.error(`No argument mapping exists for '${key}'`);
        return [];
    }
    if (argMapping[key].warningMessage) {
        logger_1.default.warn(argMapping[key].warningMessage);
        return [];
    }
    if (argMapping[key].arg) {
        switch (argMapping[key].mapper) {
            case 'string':
                return [argMapping[key].arg, `${options[key]}`];
            case 'flag':
                return options[key] ? [argMapping[key].arg] : [];
            default:
                logger_1.default.error(`Argument mapper for '${key}' maps to '${argMapping[key].arg}' with unknown mapper type '${argMapping[key].mapper}'`);
                return [];
        }
    }
    if (typeof argMapping[key] === 'function') {
        return argMapping[key](options[key]);
    }
    logger_1.default.error(`The argument mapper completely failed to find a mapping for '${key}'. This is a bug in pact-js-core`);
    return [];
})
    .reduce((acc, current) => [...acc, ...current], []);
exports.argumentMapper = argumentMapper;
//# sourceMappingURL=index.js.map