"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.libName = exports.initialiseFfi = void 0;
const ffi = require("ffi-napi");
const path = require("path");
const PLATFORM_LOOKUP = {
    linux: 'linux',
    darwin: 'osx',
    win32: 'windows',
};
const ARCH_LOOKUP = { x64: 'x86_64' };
const EXTENSION_LOOKUP = {
    'osx-x86_64': 'dylib',
    'linux-x86_64': 'so',
    'windows-x86_64': 'dll',
};
const initialiseFfi = (filename, description) => ffi.Library(path.resolve(__dirname, '..', '..', '..', 'ffi', filename), description);
exports.initialiseFfi = initialiseFfi;
const libName = (library, version) => {
    const arch = ARCH_LOOKUP[process.arch];
    const platform = PLATFORM_LOOKUP[process.platform];
    if (!arch || !platform) {
        throw new Error(`Pact does not currently support the operating system and architecture combination '${process.platform}/${process.arch}'`);
    }
    const prefix = `${platform}-${arch}`;
    const extension = EXTENSION_LOOKUP[prefix];
    if (!extension) {
        throw new Error(`Pact doesn't know what library to use for the architecture combination '${process.platform}/${process.arch}'`);
    }
    return `${version}-${library}-${prefix}.${extension}`;
};
exports.libName = libName;
//# sourceMappingURL=index.js.map