"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.verboseIsImplied = exports.setLogLevel = void 0;
const pino = require("pino");
const pkg = require('../package.json');
const DEFAULT_LEVEL = (process.env.LOGLEVEL || 'info');
const createLogger = (level = DEFAULT_LEVEL) => {
    const pinoLogger = pino({
        level: level.toLowerCase(),
        prettyPrint: {
            messageFormat: `pact-core@${pkg.version}: {msg}`,
            translateTime: true,
        },
    });
    pinoLogger.pactCrash = (message) => {
        pinoLogger.error(pactCrashMessage(message));
    };
    return pinoLogger;
};
const pactCrashMessage = (extraMessage) => `!!!!!!!!! PACT CRASHED !!!!!!!!!

${extraMessage}

This is almost certainly a bug in pact-js-core. It would be great if you could
open a bug report at: https://github.com/pact-foundation/pact-js-core/issues
so that we can fix it.

There is additional debugging information above. If you open a bug report, 
please rerun with logLevel: 'debug' set in the VerifierOptions, and include the
full output.

SECURITY WARNING: Before including your log in the issue tracker, make sure you
have removed sensitive info such as login credentials and urls that you don't want
to share with the world.

Lastly, we're sorry about this!
`;
const logger = createLogger();
const setLogLevel = (wantedLevel) => {
    if (wantedLevel) {
        logger.level =
            typeof wantedLevel === 'string'
                ? wantedLevel.toLowerCase()
                : logger.levels.labels[wantedLevel];
    }
    return logger.levels.values[logger.level];
};
exports.setLogLevel = setLogLevel;
const verboseIsImplied = () => logger.level === 'trace' || logger.level === 'debug';
exports.verboseIsImplied = verboseIsImplied;
exports.default = logger;
//# sourceMappingURL=logger.js.map