"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.argMapping = void 0;
const url = require("url");
const filesystem_1 = require("./filesystem");
exports.argMapping = {
    providerBaseUrl: (providerBaseUrl) => {
        const u = url.parse(providerBaseUrl);
        return u && u.port && u.hostname
            ? ['--port', u.port, '--hostname', u.hostname]
            : [];
    },
    logLevel: (logLevel) => ['--loglevel', logLevel],
    provider: { arg: '--provider-name', mapper: 'string' },
    pactUrls: (pactUrls) => pactUrls.reduce((acc, uri) => {
        switch (filesystem_1.getUriType(uri)) {
            case 'URL':
                return [...acc, '--url', uri];
            case 'DIRECTORY':
                return [...acc, '--dir', uri];
            case 'FILE':
                return [...acc, '--file', uri];
            default:
                return acc;
        }
    }, []),
    pactBrokerUrl: { arg: '--broker-url', mapper: 'string' },
    pactBrokerUsername: { arg: '--user', mapper: 'string' },
    pactBrokerPassword: { arg: '--password', mapper: 'string' },
    pactBrokerToken: { arg: '--broker-token', mapper: 'string' },
    consumerVersionTags: (tags) => [
        '--consumer-version-tags',
        Array.isArray(tags) ? tags.join(',') : tags,
    ],
    providerVersionTags: (tags) => [
        '--provider-version-tags',
        Array.isArray(tags) ? tags.join(',') : tags,
    ],
    providerStatesSetupUrl: { arg: '--state-change-url', mapper: 'string' },
    providerVersion: { arg: '--provider-version', mapper: 'string' },
    includeWipPactsSince: { arg: '--include-wip-pacts-since', mapper: 'string' },
    consumerVersionSelectors: (selectors) => selectors
        .map((s) => [
        '--consumer-version-selectors',
        JSON.stringify(s),
    ])
        .reduce((acc, current) => [...acc, ...current], []),
    publishVerificationResult: { arg: '--publish', mapper: 'flag' },
    enablePending: { arg: '--enable-pending', mapper: 'flag' },
    timeout: { arg: '--request-timeout', mapper: 'string' },
    format: {
        warningMessage: "All output is now on standard out, setting 'format' has no effect",
    },
    out: {
        warningMessage: "All output is now on standard out, setting 'out' has no effect",
    },
    logDir: {
        warningMessage: 'Setting logDir is deprecated as all logs are now on standard out',
    },
    verbose: {
        warningMessage: "Verbose mode is deprecated and has no effect, please use logLevel: 'DEBUG' instead",
    },
    monkeypatch: {
        warningMessage: 'The undocumented feature monkeypatch is no more, please file an issue if you were using it and need this functionality',
    },
    customProviderHeaders: {
        warningMessage: 'customProviderHeaders have been removed. This functionality is provided by request filters in a much more flexible way',
    },
};
//# sourceMappingURL=arguments.js.map