"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Verifier = void 0;
const logger_1 = require("../logger");
const promise_timeout_1 = require("promise-timeout");
const nativeVerifier_1 = require("./nativeVerifier");
const validateOptions_1 = require("./validateOptions");
const applyDefaults = (options) => (Object.assign({ timeout: 30000, logLevel: 'info' }, options));
class Verifier {
    constructor(options) {
        this.options = validateOptions_1.validateOptions(applyDefaults(options));
    }
    verify() {
        logger_1.default.info('Verifying Pact Files');
        return promise_timeout_1.timeout(nativeVerifier_1.verify(this.options), this.options.timeout).catch((err) => {
            if (err instanceof promise_timeout_1.TimeoutError) {
                throw new Error(`Timeout waiting for verification process to complete`);
            }
            throw err;
        });
    }
}
exports.Verifier = Verifier;
exports.default = (options) => new Verifier(options);
//# sourceMappingURL=index.js.map