"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.verify = void 0;
const verifier_1 = require("../ffi/verifier");
const logger_1 = require("../logger");
const arguments_1 = require("./arguments");
const argumentMapper_1 = require("../ffi/argumentMapper");
const VERIFICATION_SUCCESSFUL = 0;
const VERIFICATION_FAILED = 1;
const INVALID_ARGUMENTS = 4;
const LOG_ENV_VAR_NAME = 'PACT_LOG_LEVEL';
const verify = (opts) => {
    const verifierLib = verifier_1.getVerifierLib();
    return new Promise((resolve, reject) => {
        process.env[LOG_ENV_VAR_NAME] = opts.logLevel;
        verifierLib.init(LOG_ENV_VAR_NAME);
        const request = argumentMapper_1.argumentMapper(arguments_1.argMapping, opts)
            .map((s) => s.replace('\n', ''))
            .join('\n');
        logger_1.default.debug('sending arguments to FFI:');
        logger_1.default.debug(request);
        verifierLib.verify.async(request, (err, res) => {
            logger_1.default.debug(`response from verifier: ${err}, ${res}`);
            if (err) {
                logger_1.default.error(err);
                logger_1.default.pactCrash('The underlying pact core returned an error through the ffi interface');
                reject(err);
            }
            else {
                switch (res) {
                    case VERIFICATION_SUCCESSFUL:
                        logger_1.default.info('Verification successful');
                        resolve(`finished: ${res}`);
                        break;
                    case VERIFICATION_FAILED:
                        logger_1.default.error('Verification unsuccessful');
                        reject(new Error('Verfication failed'));
                        break;
                    case INVALID_ARGUMENTS:
                        logger_1.default.pactCrash('The underlying pact core was invoked incorrectly.');
                        reject(new Error('Verification was unable to run'));
                        break;
                    default:
                        logger_1.default.pactCrash('The underlying pact core crashed in an unexpected way.');
                        reject(new Error('Pact core crashed'));
                        break;
                }
            }
        });
    });
};
exports.verify = verify;
//# sourceMappingURL=nativeVerifier.js.map